==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebSliderDescription } from "./WebSliderDescription";
/**
 * @hidden
 */
var WebSliderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSliderDescriptionMetadata, _super);
    function WebSliderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderDescriptionMetadata.b = function (a) {
        if (WebSliderDescriptionMetadata.a == null) {
            WebSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderDescriptionMetadata.c(WebSliderDescriptionMetadata.a);
        }
        if (a.k(WebSliderDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSliderDescriptionMetadata.a);
        WebNumberEventArgsDescriptionMetadata.d(a);
    };
    WebSliderDescriptionMetadata.c = function (a) {
        WebSliderBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Slider");
        a.item("__tagNameWC", "String:igc-slider");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Value", "Number:double");
        a.item("AriaLabel", "String");
        a.item("InputRef", "EventRef::input");
        a.item("ChangeRef", "EventRef::change");
    };
    WebSliderDescriptionMetadata.d = function (a) {
        WebSliderDescriptionMetadata.b(a);
        a.ac("WebSlider", function () { return new WebSliderDescription(); });
        a.ab("WebSlider", WebSliderDescriptionMetadata.a);
    };
    WebSliderDescriptionMetadata.$t = markType(WebSliderDescriptionMetadata, 'WebSliderDescriptionMetadata');
    WebSliderDescriptionMetadata.a = null;
    return WebSliderDescriptionMetadata;
}(Base));
export { WebSliderDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebSliderDescription } from "./WebSliderDescription";
/**
 * @hidden
 */
var WebSliderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSliderDescriptionMetadata, _super);
    function WebSliderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderDescriptionMetadata.b = function (a) {
        if (WebSliderDescriptionMetadata.a == null) {
            WebSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderDescriptionMetadata.c(WebSliderDescriptionMetadata.a);
        }
        if (a.k(WebSliderDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebSliderDescriptionMetadata.a);
        WebNumberEventArgsDescriptionMetadata.d(a);
    };
    WebSliderDescriptionMetadata.c = function (a) {
        WebSliderBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Slider");
        a.item("__tagNameWC", "String:igc-slider");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Value", "Number:double");
        a.item("DefaultValue", "Unknown");
        a.item("Name", "String");
        a.item("Invalid", "Boolean");
        a.item("InputRef", "EventRef::input");
        a.item("ChangeRef", "EventRef::change");
    };
    WebSliderDescriptionMetadata.d = function (a) {
        WebSliderDescriptionMetadata.b(a);
        a.ae("WebSlider", function () { return new WebSliderDescription(); });
        a.ad("WebSlider", WebSliderDescriptionMetadata.a);
    };
    WebSliderDescriptionMetadata.$t = markType(WebSliderDescriptionMetadata, 'WebSliderDescriptionMetadata');
    WebSliderDescriptionMetadata.a = null;
    return WebSliderDescriptionMetadata;
}(Base));
export { WebSliderDescriptionMetadata };
